@@ -30,31 +30,39 @@
 #include <qiodevice.h>
 #include <qlabel.h>
 #include <qmainwindow.h>
-#include <qobjectlist.h>
+#include <qobject.h>
 #include <qstring.h>
 #include <qtabwidget.h>
 #include <qwidget.h>
-#include <qcursor.h>
+//Added by qt3to4:
+#include <QPixmap>
 
 /* OTHER INCLUDES */
 #include "instance.h"
-#include <kommanderwidget.h>
-#include <kommanderwindow.h>
-#include <kommanderfactory.h>
-#include <specials.h>
-#include <fileselector.h>
+#include "kommanderadaptor.h"  //d-bus include
+#include "kommanderwidget.h"
+#include "kommanderwindow.h"
+#include "kommanderfactory.h"
+#include "specials.h"
+#include "fileselector.h"
+#include "kommanderversion.h"
+
+#include "specialinformation.h"
 
 Instance::Instance()
-  : DCOPObject("KommanderIf"), m_instance(0), m_textInstance(0), m_parent(0)
+  : m_instance(0), m_textInstance(0), m_parent(0)
 {
   SpecialInformation::registerSpecials();
+  new KommanderAdaptor(this);
+  QDBusConnection::sessionBus().registerObject("/Kommander", this); 
 }
 
 Instance::Instance(QWidget *a_parent)
-  : DCOPObject("KommanderIf"), m_instance(0), m_textInstance(0),
-  m_parent(a_parent)
+  :  m_instance(0), m_textInstance(0), m_parent(a_parent)
 {
   SpecialInformation::registerSpecials();
+  new KommanderAdaptor(this);
+  QDBusConnection::sessionBus().registerObject("/Kommander", this);  
 }
 
 void Instance::addCmdlineArguments(const QStringList& args)
@@ -65,7 +73,7 @@ void Instance::addCmdlineArguments(const QStringList& args)
   QStringList stdArgs;
   for (QStringList::ConstIterator it = args.begin(); it != args.end(); ++it)
   {
-    int pos = (*it).find('=');
+    int pos = (*it).indexOf('=');
     if (pos != -1)
        m_textInstance->setGlobal((*it).left(pos), (*it).mid(pos+1));
     else
@@ -86,7 +94,7 @@ Instance::~Instance()
 }
 
 /** Builds the instance */
-bool Instance::build(const KURL& fname)
+bool Instance::build(const KUrl& fname)
 {
   delete m_instance;
   m_instance = 0;
@@ -99,11 +107,11 @@ bool Instance::build(const KURL& fname)
   KommanderFactory::loadPlugins();
 
   if (fname.isValid())
-    m_instance = KommanderFactory::create(fname.path());
+    m_instance = KommanderFactory::create(fname.path(), 0L, dynamic_cast<QWidget*>(parent()));
   else
   {
     QFile inputFile;
-    inputFile.open(IO_ReadOnly, stdin);
+    inputFile.open(stdin, IO_ReadOnly);
     m_instance = KommanderFactory::create(&inputFile);
   }
 
@@ -114,8 +122,9 @@ bool Instance::build(const KURL& fname)
     return false;
   }
 
-  KommanderWindow* window = dynamic_cast<KommanderWindow*>(m_instance);  if (window)
-    window->setFileName(fname.path().local8Bit());
+  KommanderWindow* window = dynamic_cast<KommanderWindow*>((QWidget*)m_instance);  
+  if (window)
+    window->setFileName(fname.path().toLocal8Bit());
 
   // FIXME : Should verify that all of the widgets in the dialog derive from KommanderWidget
   m_textInstance = kommanderWidget(m_instance);
@@ -124,8 +133,8 @@ bool Instance::build(const KURL& fname)
   {
     if (m_instance)
     {
-      QObjectList* widgets = m_instance->queryList();
-      for (QObject* w = widgets->first(); w; w = widgets->next())
+      QObjectList widgets = m_instance->findChildren<QObject*>();
+      foreach (QObject *w, widgets)
         if (kommanderWidget(w))
         {
           m_textInstance = kommanderWidget(w);
@@ -143,6 +152,8 @@ bool Instance::build(const KURL& fname)
   {
       m_textInstance->setGlobal("KDDIR", fname.directory());
       m_textInstance->setGlobal("NAME", fname.fileName());
+      m_textInstance->setGlobal("_PID", QString().setNum(getpid()));
+      m_textInstance->setGlobal("VERSION", KOMMANDER_VERSION);
   }
   return true;
 }
@@ -154,11 +165,11 @@ bool Instance::run()
 
   // Handle both dialogs and main windows
   if (m_instance->inherits("QDialog"))
-    ((QDialog*)m_instance)->exec();
+    dynamic_cast<QDialog*>((QWidget*)m_instance)->exec();
   else if (m_instance->inherits("QMainWindow"))
   {
     kapp->setMainWidget(m_instance);
-    ((QMainWindow*)m_instance)->show();
+    dynamic_cast<QMainWindow*>((QWidget*)m_instance)->show();
     kapp->exec();
   }
   else return false;
@@ -175,12 +186,12 @@ void Instance::setParent(QWidget *a_parent)
   m_parent = a_parent;
 }
 
-bool Instance::isFileValid(const KURL& fname) const
+bool Instance::isFileValid(const KUrl& fname) const
 {
   if (!QFileInfo(fname.path()).exists())
   {
     KMessageBox::sorry(0, i18n("<qt>Kommander file<br><b>%1</b><br>does not "
-      "exist.</qt>").arg(fname.path()));
+      "exist.</qt>", fname.path()));
     return false;
   }
 
@@ -201,16 +212,21 @@ bool Instance::isFileValid(const KURL& fname) const
 
   bool inTemp = false;
   for (QStringList::ConstIterator I = tmpDirs.begin(); I != tmpDirs.end(); ++I)
-    if (fname.directory(false).startsWith(*I))
+    if (fname.directory(KUrl::AppendTrailingSlash).startsWith(*I))
       inTemp = true;
 
   if (inTemp)
   {
-     if (KMessageBox::warningContinueCancel(0, i18n("<qt>This dialog is running from your <i>/tmp</i> directory. "
+    if (KMessageBox::warningContinueCancel(m_parent, i18n("<qt>This dialog is running from your <i>/tmp</i> directory. "
          " This may mean that it was run from a KMail attachment or from a webpage. "
          "<p>Any script contained in this dialog will have write access to all of your home directory; "
          "<b>running such dialogs may be dangerous: </b>"
-             "<p>are you sure you want to continue?</qt>"), QString(), i18n("Run Nevertheless")) == KMessageBox::Cancel)
+             "<p>are you sure you want to continue?</qt>"), QString(), KGuiItem(i18n("Run Nevertheless"))) == KMessageBox::Cancel)
+       return false;
+  }
+  if (!QFileInfo(fname.path()).isExecutable())
+  {
+    if (KMessageBox::warningContinueCancel(m_parent, i18n("<qt>The Kommander file <i>%1</i> does not have the <b>executable attribute</b> set and could possibly contain dangerous exploits.<p>If you trust the scripting (viewable in kmdr-editor) in this program, make it executable to get rid of this warning.<p>Are you sure you want to continue?</qt>", fname.pathOrUrl()), QString(), KGuiItem(i18n("Run Nevertheless"))) == KMessageBox::Cancel)
        return false;
   }
   return true;
@@ -232,14 +248,14 @@ void Instance::setVisible(const QString& widgetName, bool visible)
 {
   QObject* child = stringToWidget(widgetName);
   if (child && child->inherits("QWidget"))
-    ((QWidget*)child)->setShown(visible);
+    ((QWidget*)child)->setVisible(visible);
 }
 
 void Instance::setText(const QString& widgetName, const QString& text)
 {
   QObject* child = stringToWidget(widgetName);
   if (kommanderWidget(child))
-    kommanderWidget(child)->handleDCOP(DCOP::setText, text);
+    kommanderWidget(child)->handleDBUS(DBUS::setText, text);
   else if (child && child->inherits("QLabel"))
   {
     QLabel* label = (QLabel*)child;
@@ -258,7 +274,7 @@ QString Instance::text(const QString& widgetName)
 {
   QObject* child = stringToWidget(widgetName);
   if (kommanderWidget(child))
-    return kommanderWidget(child)->handleDCOP(DCOP::text);
+    return kommanderWidget(child)->handleDBUS(DBUS::text);
   else if (child && child->inherits("QLabel"))
     return ((QLabel*)child)->text();
   return QString();
@@ -268,7 +284,7 @@ void Instance::setSelection(const QString& widgetName, const QString& text)
 {
   QObject* child = stringToWidget(widgetName);
   if (kommanderWidget(child))
-    kommanderWidget(child)->handleDCOP(DCOP::setSelection, text);
+    kommanderWidget(child)->handleDBUS(DBUS::setSelection, text);
   else if (child && child->inherits("QLabel"))
     ((QLabel*)child)->setText(text);
 }
@@ -277,7 +293,7 @@ QString Instance::selection(const QString& widgetName)
 {
   QObject* child = stringToWidget(widgetName);
   if (kommanderWidget(child))
-    return kommanderWidget(child)->handleDCOP(DCOP::selection);
+    return kommanderWidget(child)->handleDBUS(DBUS::selection);
   return QString();
 }
 
@@ -285,7 +301,7 @@ int Instance::currentItem(const QString &widgetName)
 {
   QObject* child = stringToWidget(widgetName);
   if (kommanderWidget(child))
-    return kommanderWidget(child)->handleDCOP(DCOP::currentItem).toInt();
+    return kommanderWidget(child)->handleDBUS(DBUS::currentItem).toInt();
   return -1;
 }
 
@@ -293,15 +309,15 @@ QString Instance::item(const QString &widgetName, int i)
 {
   QObject* child = stringToWidget(widgetName);
   if (kommanderWidget(child))
-    return kommanderWidget(child)->handleDCOP(DCOP::item, QString::number(i));
-  return QString();
+    return kommanderWidget(child)->handleDBUS(DBUS::item, QString::number(i));
+  return QString();      
 }
 
 void Instance::removeItem(const QString &widgetName, int index)
 {
   QObject* child = stringToWidget(widgetName);
   if (kommanderWidget(child))
-    kommanderWidget(child)->handleDCOP(DCOP::removeItem, QString::number(index));
+    kommanderWidget(child)->handleDBUS(DBUS::removeItem, QString::number(index));
 }
 
 void Instance::insertItem(const QString &widgetName, const QString &item, int index)
@@ -311,7 +327,7 @@ void Instance::insertItem(const QString &widgetName, const QString &item, int in
   {
     QStringList args(item);
     args += QString::number(index);
-    kommanderWidget(child)->handleDCOP(DCOP::insertItem, args);
+    kommanderWidget(child)->handleDBUS(DBUS::insertItem, args);
   }
 }
 
@@ -322,7 +338,7 @@ void Instance::insertItems(const QString &widgetName, const QStringList &items,
   {
     QStringList args(items.join("\n"));
     args += QString::number(index);
-    kommanderWidget(child)->handleDCOP(DCOP::insertItems, args);
+    kommanderWidget(child)->handleDBUS(DBUS::insertItems, args);
   }
 }
 
@@ -330,7 +346,7 @@ int Instance::findItem(const QString &widgetName, const QString& item)
 {
   QObject* child = stringToWidget(widgetName);
   if (kommanderWidget(child))
-    return kommanderWidget(child)->handleDCOP(DCOP::findItem, item).toInt();
+    return kommanderWidget(child)->handleDBUS(DBUS::findItem, item).toInt();
   return -1;
 }
 
@@ -338,14 +354,14 @@ void Instance::addUniqueItem(const QString &widgetName, const QString &item)
 {
   QObject* child = stringToWidget(widgetName);
   if (kommanderWidget(child))
-    kommanderWidget(child)->handleDCOP(DCOP::addUniqueItem, item);
+    kommanderWidget(child)->handleDBUS(DBUS::addUniqueItem, item);
 }
 
 int Instance::itemDepth(const QString &widgetName, int index)
 {
   QObject* child = stringToWidget(widgetName);
   if (kommanderWidget(child))
-    return kommanderWidget(child)->handleDCOP(DCOP::itemDepth, QString::number(index)).toInt();
+    return kommanderWidget(child)->handleDBUS(DBUS::itemDepth, QString::number(index)).toInt();
   return -1;
 }
 
@@ -353,7 +369,7 @@ QString Instance::itemPath(const QString &widgetName, int index)
 {
   QObject* child = stringToWidget(widgetName);
   if (kommanderWidget(child))
-    return kommanderWidget(child)->handleDCOP(DCOP::itemPath, QString::number(index));
+    return kommanderWidget(child)->handleDBUS(DBUS::itemPath, QString::number(index));
   return QString();
 }
 
@@ -365,7 +381,7 @@ void Instance::setPixmap(const QString &widgetName, const QString& iconName, int
   {
     QStringList args(iconName);
     args += QString::number(index);
-    kommanderWidget(child)->handleDCOP(DCOP::setPixmap, args);
+    kommanderWidget(child)->handleDBUS(DBUS::setPixmap, args);
   }
 }
 
@@ -373,28 +389,28 @@ void Instance::clear(const QString &widgetName)
 {
   QObject* child = stringToWidget(widgetName);  
   if (kommanderWidget(child))
-    kommanderWidget(child)->handleDCOP(DCOP::clear);
+    kommanderWidget(child)->handleDBUS(DBUS::clear);
 }
 
 void Instance::setCurrentItem(const QString &widgetName, int index)
 {
   QObject* child = stringToWidget(widgetName);  
   if (kommanderWidget(child))
-    kommanderWidget(child)->handleDCOP(DCOP::setCurrentItem, QString::number(index));
+    kommanderWidget(child)->handleDBUS(DBUS::setCurrentItem, QString::number(index));
 }
 
 void Instance::setChecked(const QString &widgetName, bool checked)
 {
   QObject* child = stringToWidget(widgetName);  
   if (kommanderWidget(child))
-    kommanderWidget(child)->handleDCOP(DCOP::setChecked, checked ? "true" : "false");
+    kommanderWidget(child)->handleDBUS(DBUS::setChecked, checked ? "true" : "false");
 }
 
 bool Instance::checked(const QString &widgetName)
 {
   QObject* child = stringToWidget(widgetName);
   if (kommanderWidget(child))
-    return kommanderWidget(child)->handleDCOP(DCOP::checked, widgetName) == "1";
+    return kommanderWidget(child)->handleDBUS(DBUS::checked, widgetName) == "1";
   return false;
 }
 
@@ -402,7 +418,7 @@ void Instance::setAssociatedText(const QString &widgetName, const QString& text)
 {
   QObject* child = stringToWidget(widgetName);  
   if (kommanderWidget(child))
-    kommanderWidget(child)->setAssociatedText(QStringList::split('\n', text, true));
+    kommanderWidget(child)->setAssociatedText(text.split('\n', QString::KeepEmptyParts));
 }
 
 QStringList Instance::associatedText(const QString &widgetName)
@@ -410,30 +426,34 @@ QStringList Instance::associatedText(const QString &widgetName)
   QObject* child = stringToWidget(widgetName);  
   if (kommanderWidget(child))
     kommanderWidget(child)->associatedText();  
-  return QString();
+  return QStringList();
 }
 
 QString Instance::type(const QString& widget)
 {
   QObject* child = stringToWidget(widget);  
-  if (child->inherits("QWidget"))
-    return child->className();
+  if (child && child->inherits("QWidget"))
+    return child->metaObject()->className();
   return QString();
 }
 
 QStringList Instance::children(const QString& parent, bool recursive)
 {
   QStringList matching;
-  QObject* child = stringToWidget(parent);
-  QObjectList* widgets;
+  QObject* child = stringToWidget(parent);  
+  QList<QWidget *> widgets;
   if (!child)
      child = m_instance; 
   if (child->inherits("QWidget"))
   {
-    widgets = child->queryList("QWidget", 0, false, recursive);
-    for (QObject* w = widgets->first(); w; w = widgets->next())
-      if (w->name() && kommanderWidget(w))
-        matching.append(w->name());
+    widgets = child->findChildren<QWidget *>();
+    QListIterator<QWidget *> widgetsit(widgets);
+    while(widgetsit.hasNext())
+    {
+      QWidget* w = widgetsit.next();
+      if (!w->objectName().isEmpty() && kommanderWidget(w))
+        matching.append(w->objectName());
+    }
   }
   return matching;
 }
@@ -442,28 +462,29 @@ void Instance::setMaximum(const QString &widgetName, int value)
 {
   QObject* child = stringToWidget(widgetName);  
   if (kommanderWidget(child))
-    kommanderWidget(child)->handleDCOP(DCOP::setMaximum, QString::number(value));
+    kommanderWidget(child)->handleDBUS(DBUS::setMaximum, QString::number(value));
 }
 
-void Instance::execute(const QString &widgetName)
+QString Instance::execute(const QString &widgetName)
 {
   QObject* child = stringToWidget(widgetName);  
   if (kommanderWidget(child))
-    kommanderWidget(child)->handleDCOP(DCOP::execute);
+    return kommanderWidget(child)->handleDBUS(DBUS::execute);
+  return "";
 }
 
 void Instance::cancel(const QString &widgetName)
 {
   QObject* child = stringToWidget(widgetName);  
   if (kommanderWidget(child))
-    kommanderWidget(child)->handleDCOP(DCOP::cancel);
+    kommanderWidget(child)->handleDBUS(DBUS::cancel);
 }
 
 int Instance::count(const QString &widgetName)
 {
   QObject* child = stringToWidget(widgetName);
   if (kommanderWidget(child))
-    return kommanderWidget(child)->handleDCOP(DCOP::count).toInt();
+    return kommanderWidget(child)->handleDBUS(DBUS::count).toInt();
   return -1;
 }
 
@@ -471,7 +492,7 @@ int Instance::currentColumn(const QString &widgetName)
 {
   QObject* child = stringToWidget(widgetName);
   if (kommanderWidget(child))
-    return kommanderWidget(child)->handleDCOP(DCOP::currentColumn).toInt();
+    return kommanderWidget(child)->handleDBUS(DBUS::currentColumn).toInt();
   return -1;
 }
 
@@ -479,7 +500,7 @@ int Instance::currentRow(const QString &widgetName)
 {
   QObject* child = stringToWidget(widgetName);
   if (kommanderWidget(child))
-    return kommanderWidget(child)->handleDCOP(DCOP::currentRow).toInt();
+    return kommanderWidget(child)->handleDBUS(DBUS::currentRow).toInt();
   return -1;
 }
 
@@ -490,7 +511,7 @@ void Instance::insertRow(const QString &widgetName, int row, int count)
   {
     QStringList args(QString::number(row));
     args += QString::number(count);
-    kommanderWidget(child)->handleDCOP(DCOP::insertRow, args);
+    kommanderWidget(child)->handleDBUS(DBUS::insertRow, args);
   }
 }
 
@@ -501,7 +522,7 @@ void Instance::insertColumn(const QString &widgetName, int column, int count)
   {
     QStringList args(QString::number(column));
     args += QString::number(count);
-    kommanderWidget(child)->handleDCOP(DCOP::insertColumn, args);
+    kommanderWidget(child)->handleDBUS(DBUS::insertColumn, args);
   }
 }
 
@@ -513,7 +534,7 @@ void Instance::setCellText(const QString &widgetName, int row, int column, const
     QStringList args(QString::number(row));
     args += QString::number(column);
     args += text;
-    kommanderWidget(child)->handleDCOP(DCOP::setCellText, args);
+    kommanderWidget(child)->handleDBUS(DBUS::setCellText, args);
   }
 }
 
@@ -524,9 +545,10 @@ QString Instance::cellText(const QString &widgetName, int row, int column)
   {
     QStringList args(QString::number(row));
     args += QString::number(column);
-    return kommanderWidget(child)->handleDCOP(DCOP::cellText, args);
+    return kommanderWidget(child)->handleDBUS(DBUS::cellText, args);
   }
-  else return QString();
+  else
+    return QString();
 }
 
 void Instance::removeRow(const QString &widgetName, int row, int count)
@@ -536,7 +558,7 @@ void Instance::removeRow(const QString &widgetName, int row, int count)
   {
     QStringList args(QString::number(row));
     args += QString::number(count);
-    kommanderWidget(child)->handleDCOP(DCOP::removeRow, args);
+    kommanderWidget(child)->handleDBUS(DBUS::removeRow, args);
   }
 }
 
@@ -547,7 +569,7 @@ void Instance::removeColumn(const QString &widgetName, int column, int count)
   {
     QStringList args(QString::number(column));
     args += QString::number(count);
-    kommanderWidget(child)->handleDCOP(DCOP::removeColumn, args);
+    kommanderWidget(child)->handleDBUS(DBUS::removeColumn, args);
   }
 }
 
@@ -558,7 +580,7 @@ void Instance::setRowCaption(const QString &widgetName, int row, const QString&
   {
     QStringList args(QString::number(row));
     args += text;
-    kommanderWidget(child)->handleDCOP(DCOP::setRowCaption, args);
+    kommanderWidget(child)->handleDBUS(DBUS::setRowCaption, args);
   }
 }
 
@@ -569,7 +591,7 @@ void Instance::setColumnCaption(const QString &widgetName, int column, const QSt
   {
     QStringList args(QString::number(column));
     args += text;
-    kommanderWidget(child)->handleDCOP(DCOP::setColumnCaption, args);
+    kommanderWidget(child)->handleDBUS(DBUS::setColumnCaption, args);
   }
 }
 
@@ -595,7 +617,7 @@ void Instance::setGlobal(const QString& variableName, const QString& value)
 
 QObject* Instance::stringToWidget(const QString& name)
 {
-  return m_instance->child(name);
+  return m_instance->findChild<QObject *>(name);
 }
 
 KommanderWidget* Instance::kommanderWidget(QObject* object)
@@ -632,7 +654,7 @@ void Instance::insertTab(const QString &widgetName, const QString &label, int in
   l << label;
   l << QString::number(index);
   if (kommanderWidget(child))
-    kommanderWidget(child)->handleDCOP(DCOP::insertTab, l);  
+    kommanderWidget(child)->handleDBUS(DBUS::insertTab, l);  
 }
 
 void Instance::addListItems(const QString &widgetName, const QStringList &items, int index)
