@@ -1,24 +1,29 @@
 
-/***************************************************************************
-                          main.c  - main fiule for xsldbg
-                             -------------------
-    begin                : Sat Dec 22 2001
-    copyright            : (C) 2001 by Keith Isdale
-    email                : k_isdale@tpg.com.au
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/**
+ *
+ *  This file is part of the kdewebdev package
+ *  Copyright (c) 2001 Keith Isdale <keith@kdewebdev.org>
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU General Public License as
+ *  published by the Free Software Foundation; either version 2 of
+ *  the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public License
+ *  along with this library; see the file COPYING.LIB.  If not, write to
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
+ **/
 
 #include "kxsldbgpart/libxsldbg/xsldbg.h"
 
 #include <libxslt/xsltutils.h>
+#include <version.h>
 
 #ifdef HAVE_READLINE
 #include <readline/readline.h>
@@ -30,10 +35,8 @@
 #include <string.h>
 #include "kxsldbgpart/libxsldbg/xsldbgmsg.h"
 #include "kxsldbgpart/libxsldbg/xsldbgio.h"
-#include "kxsldbgpart/libxsldbg/xsldbg.h"
 #include "kxsldbgpart/libxsldbg/options.h"
 
-#include <libxslt/xsltutils.h>
 #include <kapplication.h>
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
@@ -50,60 +53,13 @@ static xmlChar * xslDbgShellReadlineSimple(xmlChar * prompt);
 
 static const char *description = I18N_NOOP("A KDE console application for xsldbg, an XSLT debugger");
 
-static const char *version = VERSION;
-
-static const KCmdLineOptions options[] =
-{
-    { "shell",		I18N_NOOP("Start a shell"), 0},
-    { "cd <path>",	I18N_NOOP("Path to change into before loading files"), 0},
-    { "param <name>:<value>",I18N_NOOP("Add a parameter named <name> and value <value> to XSL environment"), 0},
-    { "lang <LANG>", 	I18N_NOOP("Use ISO 639 language code specified; for example en_US"), 0},    { "output file", 	I18N_NOOP("Save to a given file. See output command documentation"), 0},
-    { "version",	I18N_NOOP("Show the version of libxml and libxslt used"), 0},
-    { "verbose", 	I18N_NOOP("Show logs of what is happening"), 0},
-    { "timing", 	I18N_NOOP("Display the time used"), 0},
-    { "repeat", 	I18N_NOOP("Run the transformation 20 times"), 0},
-#ifdef LIBXML_DEBUG_ENABLED
-    { "debug", 		I18N_NOOP("Dump the tree of the result instead"), 0},
-#endif
-    { "novalid", 	I18N_NOOP("Disable the DTD loading phase"), 0},
-    { "noout", 		I18N_NOOP("Disable the output of the result"), 0},
-    { "maxdepth val", 	I18N_NOOP("Increase the maximum depth"), 0},
-
-#ifdef LIBXML_HTML_ENABLED
-    { "html", 		I18N_NOOP("The input document is(are) an HTML file(s)"), 0},
-#endif
-
-#ifdef LIBXML_DOCB_ENABLED
-    { "docbook", 	I18N_NOOP("The input document is SGML docbook"), 0},
-#endif
-
-    { "nonet", 		I18N_NOOP("Disable the fetching DTDs or entities over network"), 0},
-
-#ifdef LIBXML_CATALOG_ENABLED
-    { "catalogs", 	I18N_NOOP("Use the catalogs from $SGML_CATALOG_FILES"), 0},
-#endif
-
-#ifdef LIBXML_XINCLUDE_ENABLED
-    { "noxinclude", 	I18N_NOOP("Disable XInclude processing on document input"), 0},
-#endif
-
-    { "profile", 	I18N_NOOP("Print profiling informations"), 0},
-    { "nogdb", 		I18N_NOOP("Do not run gdb compatability mode and print less information"), 0},
-    { "autoencode", 	I18N_NOOP("Detect and use encodings in the stylesheet"), 0},
-    { "utf8input", 	I18N_NOOP("Treat command line input as encoded in UTF-8"), 0},
-    { "preferhtml", 	I18N_NOOP("Use HTML output when generating search reports"), 0},
-    { "stdout", 	I18N_NOOP("Print all error messages to stdout, normally error messages go to stderr"), 0},
-    { "noautorestart", 	I18N_NOOP("Disable the automatic restarting of execution when current processing pass is complete"), 0},
-    { "+XSLSource", 	I18N_NOOP("XSL script to run"), 0},
-    { "+XMLData",       I18N_NOOP("XML data to be transformed"), 0},
-    KCmdLineLastOption // End of options.
-};
+static const char *version = KXSLDBG_VERSION;
 
 class XsldbgApp : public KApplication
 {
  public:
     XsldbgApp()
-	:KApplication(false, false)
+	:KApplication(false)
     {
 	xsldbgSetAppFunc(notifyXsldbgAppSimple);
 	xsldbgSetAppStateFunc(notifyStateXsldbgAppSimple);
@@ -119,24 +75,64 @@ class XsldbgApp : public KApplication
 
 int main(int argc, char **argv)
 {
-    KLocale::setMainCatalogue("kxsldbg"); // Translations come from KXSLDbg's catalog
+    KLocale::setMainCatalog("kxsldbg"); // Translations come from KXSLDbg's catalog
 
-    QString xsldbgRunTimeInfo(i18n("Using libxml %1, libxslt %2 and libexslt %3\n").arg(xmlParserVersion).arg(xsltEngineVersion).arg(exsltLibraryVersion));
-    QString libxmlCompileTimeInfo(i18n("xsldbg was compiled against libxml %1, libxslt %2 and libexslt %3\n").arg(LIBXML_VERSION).arg(LIBXSLT_VERSION).arg(LIBEXSLT_VERSION));
-    QString libxsltCompileTimeInfo(i18n("libxslt %1 was compiled against libxml %2\n").arg(xsltLibxsltVersion).arg(xsltLibxmlVersion));
-    QString libexsltCompileTimeInfo(i18n("libexslt %1 was compiled against libxml %2\n").arg(exsltLibexsltVersion).arg(exsltLibxmlVersion));
+    QString xsldbgRunTimeInfo(i18n("Using libxml %1, libxslt %2 and libexslt %3\n", xmlParserVersion, xsltEngineVersion, exsltLibraryVersion));
+    QString libxmlCompileTimeInfo(i18n("xsldbg was compiled against libxml %1, libxslt %2 and libexslt %3\n", LIBXML_VERSION, LIBXSLT_VERSION, LIBEXSLT_VERSION));
+    QString libxsltCompileTimeInfo(i18n("libxslt %1 was compiled against libxml %2\n", xsltLibxsltVersion, xsltLibxmlVersion));
+    QString libexsltCompileTimeInfo(i18n("libexslt %1 was compiled against libxml %2\n", exsltLibexsltVersion, exsltLibxmlVersion));
     QString freeFormText = xsldbgRunTimeInfo + libxmlCompileTimeInfo + libxsltCompileTimeInfo + libexsltCompileTimeInfo;
 
-    KAboutData about("xsldbg", I18N_NOOP("Xsldbg"), version, description, KAboutData::License_GPL, "(C) 2003 Keith Isdale", freeFormText, 0, "k_isdale@tpg.com.au");
-    about.addAuthor( "Keith Isdale", 0, "k_isdale@tpg.com.au" );
+    KAboutData about("xsldbg", 0, ki18n("Xsldbg"), version, ki18n(description), KAboutData::License_GPL, ki18n("(C) 2003 Keith Isdale"), ki18n(freeFormText.toUtf8().constData()), 0, "keith@kdewebdev.org");
+    about.addAuthor( ki18n("Keith Isdale"), KLocalizedString(), "keith@kdewebdev.org" );
     KCmdLineArgs::init(argc, argv, &about);
+
+    KCmdLineOptions options;
+    options.add("shell", ki18n("Start a shell"));
+    options.add("cd <path>", ki18n("Path to change into before loading files"));
+    options.add("param <name>:<value>", ki18n("Add a parameter named <name> and value <value> to XSL environment"));
+    options.add("lang <LANG>", ki18n("Use ISO 639 language code specified; for example en_US"));
+    options.add("output file", ki18n("Save to a given file. See output command documentation"));
+    options.add("version", ki18n("Show the version of libxml and libxslt used"));
+    options.add("verbose", ki18n("Show logs of what is happening"));
+    options.add("timing", ki18n("Display the time used"));
+    options.add("repeat", ki18n("Run the transformation 20 times"));
+    options.add("noautoloadconfig", ki18n("Automatically load/save configuration."));
+    #ifdef LIBXML_DEBUG_ENABLED
+    options.add("debug", ki18n("Dump the tree of the result instead"));
+    #endif
+    options.add("novalid", ki18n("Disable the DTD loading phase"));
+    options.add("noout", ki18n("Disable the output of the result"));
+    options.add("maxdepth val", ki18n("Increase the maximum depth"));
+    #ifdef LIBXML_HTML_ENABLED
+    options.add("html", ki18n("The input document is(are) an HTML file(s)"));
+    #endif
+#ifdef LIBXML_DOCB_ENABLED
+    options.add("docbook", ki18n("The input document is SGML docbook"));
+    #endif
+    options.add("nonet", ki18n("Disable the fetching DTDs or entities over network"));
+    #ifdef LIBXML_CATALOG_ENABLED
+    options.add("catalogs", ki18n("Use the catalogs from $SGML_CATALOG_FILES"));
+    #endif
+#ifdef LIBXML_XINCLUDE_ENABLED
+    options.add("noxinclude", ki18n("Disable XInclude processing on document input"));
+    #endif
+    options.add("profile", ki18n("Print profiling information"));
+    options.add("nogdb", ki18n("Do not run gdb compatability mode and print less information"));
+    options.add("autoencode", ki18n("Detect and use encodings in the stylesheet"));
+    options.add("utf8input", ki18n("Treat command line input as encoded in UTF-8"));
+    options.add("preferhtml", ki18n("Use HTML output when generating search reports"));
+    options.add("stdout", ki18n("Print all error messages to stdout, normally error messages go to stderr"));
+    options.add("noautorestart", ki18n("Disable the automatic restarting of execution when current processing pass is complete"));
+    options.add("+XSLSource", ki18n("XSL script to run"));
+    options.add("+XMLData", ki18n("XML data to be transformed"));
     KCmdLineArgs::addCmdLineOptions( options );
     XsldbgApp app;
 
     return app.exec();;
 }
 
-/* Private implmentation of messaging functions */
+/* Private implementation of messaging functions */
 int notifyXsldbgAppSimple(XsldbgMessageEnum type, const void *data)
 {
   Q_UNUSED(type);
